# coding=utf-8
# --------------------------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# Licensed under the MIT License. See License.txt in the project root for
# license information.
#
# Code generated by Microsoft (R) AutoRest Code Generator 2.3.33.0
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.service_client import ServiceClient
from msrest import Configuration, Serializer, Deserializer
from .version import VERSION
from msrest.exceptions import HttpOperationError
from .operations.artifact_operations import ArtifactOperations
from .operations.credential_operations import CredentialOperations
from .operations.data_stores_operations import DataStoresOperations
from .operations.dataset_operations import DatasetOperations
from .operations.jasmine_operations import JasmineOperations
from .operations.metric_operations import MetricOperations
from .operations.model_operations import ModelOperations
from .operations.asset_operations import AssetOperations
from .operations.image_operations import ImageOperations
from .operations.operations import Operations
from .operations.swagger_operations import SwaggerOperations
from .operations.service_operations import ServiceOperations
from .operations.events_operations import EventsOperations
from .operations.experiment_operations import ExperimentOperations
from .operations.run_operations import RunOperations
from .operations.run_metric_operations import RunMetricOperations
from .operations.run_artifact_operations import RunArtifactOperations
from .operations.snapshot_operations import SnapshotOperations
from .operations.workspaces_operations import WorkspacesOperations
from .operations.usages_operations import UsagesOperations
from .operations.virtual_machine_sizes_operations import VirtualMachineSizesOperations
from .operations.machine_learning_compute_operations import MachineLearningComputeOperations
from . import models


class RestClientConfiguration(Configuration):
    """Configuration for RestClient
    Note that all parameters used to create this instance are saved as instance
    attributes.

    :param description: The description of the object.
    :type description: str
    :param expand: The option to show model details
    :type expand: bool
    :param credentials: Subscription credentials which uniquely identify
     client subscription.
    :type credentials: None
    :param str base_url: Service URL
    """

    def __init__(
            self, credentials, description=None, expand=None, base_url=None):

        if credentials is None:
            raise ValueError("Parameter 'credentials' must not be None.")
        if not base_url:
            base_url = 'http://localhost'

        super(RestClientConfiguration, self).__init__(base_url)

        self.add_user_agent('azureml._restclient/{}'.format(VERSION))

        self.description = description
        self.expand = expand
        self.credentials = credentials


class RestClient(object):
    """These APIs allow end users to operate on Azure Machine Learning Workspace resources.

    :ivar config: Configuration for client.
    :vartype config: RestClientConfiguration

    :ivar artifact: Artifact operations
    :vartype artifact: _restclient.operations.ArtifactOperations
    :ivar credential: Credential operations
    :vartype credential: _restclient.operations.CredentialOperations
    :ivar data_stores: DataStores operations
    :vartype data_stores: _restclient.operations.DataStoresOperations
    :ivar dataset: Dataset operations
    :vartype dataset: _restclient.operations.DatasetOperations
    :ivar jasmine: Jasmine operations
    :vartype jasmine: _restclient.operations.JasmineOperations
    :ivar metric: Metric operations
    :vartype metric: _restclient.operations.MetricOperations
    :ivar model: Model operations
    :vartype model: _restclient.operations.ModelOperations
    :ivar asset: Asset operations
    :vartype asset: _restclient.operations.AssetOperations
    :ivar image: Image operations
    :vartype image: _restclient.operations.ImageOperations
    :ivar operations: Operations operations
    :vartype operations: _restclient.operations.Operations
    :ivar swagger: Swagger operations
    :vartype swagger: _restclient.operations.SwaggerOperations
    :ivar service: Service operations
    :vartype service: _restclient.operations.ServiceOperations
    :ivar events: Events operations
    :vartype events: _restclient.operations.EventsOperations
    :ivar experiment: Experiment operations
    :vartype experiment: _restclient.operations.ExperimentOperations
    :ivar run: Run operations
    :vartype run: _restclient.operations.RunOperations
    :ivar run_metric: RunMetric operations
    :vartype run_metric: _restclient.operations.RunMetricOperations
    :ivar run_artifact: RunArtifact operations
    :vartype run_artifact: _restclient.operations.RunArtifactOperations
    :ivar snapshot: Snapshot operations
    :vartype snapshot: _restclient.operations.SnapshotOperations
    :ivar workspaces: Workspaces operations
    :vartype workspaces: _restclient.operations.WorkspacesOperations
    :ivar usages: Usages operations
    :vartype usages: _restclient.operations.UsagesOperations
    :ivar virtual_machine_sizes: VirtualMachineSizes operations
    :vartype virtual_machine_sizes: _restclient.operations.VirtualMachineSizesOperations
    :ivar machine_learning_compute: MachineLearningCompute operations
    :vartype machine_learning_compute: _restclient.operations.MachineLearningComputeOperations

    :param description: The description of the object.
    :type description: str
    :param expand: The option to show model details
    :type expand: bool
    :param credentials: Subscription credentials which uniquely identify
     client subscription.
    :type credentials: None
    :param str base_url: Service URL
    """

    def __init__(
            self, credentials, description=None, expand=None, base_url=None):

        self.config = RestClientConfiguration(credentials, description, expand, base_url)
        self._client = ServiceClient(self.config.credentials, self.config)

        client_models = {k: v for k, v in models.__dict__.items() if isinstance(v, type)}
        self._serialize = Serializer(client_models)
        self._deserialize = Deserializer(client_models)

        self.artifact = ArtifactOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.credential = CredentialOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.data_stores = DataStoresOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.dataset = DatasetOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.jasmine = JasmineOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.metric = MetricOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.model = ModelOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.asset = AssetOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.image = ImageOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.operations = Operations(
            self._client, self.config, self._serialize, self._deserialize)
        self.swagger = SwaggerOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.service = ServiceOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.events = EventsOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.experiment = ExperimentOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.run = RunOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.run_metric = RunMetricOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.run_artifact = RunArtifactOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.snapshot = SnapshotOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.workspaces = WorkspacesOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.usages = UsagesOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.virtual_machine_sizes = VirtualMachineSizesOperations(
            self._client, self.config, self._serialize, self._deserialize)
        self.machine_learning_compute = MachineLearningComputeOperations(
            self._client, self.config, self._serialize, self._deserialize)
